trivial doxygen cleanups
[paraslash.git] / audiod.h
index 077ce03e415f45c2937d953a8602193e7f6c68a1..3f481460e787cb16fb4c175b026e9abed0727d1f 100644 (file)
--- a/audiod.h
+++ b/audiod.h
@@ -1,30 +1,59 @@
+/*
+ * Copyright (C) 2006-2007 Andre Noll <maan@systemlinux.org>
+ *
+ * Licensed under the GPL v2. For licencing details see COPYING.
+ */
+
 /** \file audiod.h symbols exported from audiod.c */
+
+
 int num_filters(int audio_format_num);
 int get_audio_format_num(char *name);
-enum {
-       AUDIO_FORMAT_MP3,
-       AUDIO_FORMAT_OGG,
-       AUDIO_FORMAT_AAC,
-       NUM_AUDIO_FORMATS
-};
+
+/** enum of audio formats supported by para_audiod */
+enum {AUDIOD_AUDIO_FORMATS_ENUM};
+
+/** array of audio format names supported by para_audiod */
 extern const char *audio_formats[];
-#define DEFINE_AUDIO_FORMAT_ARRAY const char *audio_formats[] = {"mp3", "ogg", "aac", NULL}
+
+/** maximal number of simultaneous instances */
 #define MAX_STREAM_SLOTS 5
+
 /**
  * the possible modes of operation
  *
  * - off: disconnect from para_server
  * - on: receive status information from para_server and play the audio stream
  * - sb: only receive status information but not the audio stream
-*/
-enum {AUDIOD_OFF, AUDIOD_ON, AUDIOD_STANDBY};
+ */
+enum audiod_status_info {AUDIOD_OFF, AUDIOD_ON, AUDIOD_STANDBY};
+
+/** defines one command of para_audiod */
+struct audiod_command {
+       /** the name of the command */
+       const char *name;
+       /** pointer to the function that handles the command */
+       int (*handler)(int, int, char**);
+       /**
+        * if the command prefers to handle the full line (rather than the usual
+        * argv[] array), it stores a pointer to the corresponding line handling
+        * function here. In this case, the above \a handler pointer must be NULL.
+        */
+       int (*line_handler)(int, char*);
+       /** one-line description of the command */
+       const char *description;
+       /** summary of the command line options */
+       const char *usage;
+       /** the long help text */
+       const char *help;
+};
 
 /**
  * describes one instance of a receiver-filter-writer chain
  *
  * \sa receier_node, receiver, filter, filter_node, filter_chain, writer,
  * writer_node, writer_node_group.
 */
+ */
 struct slot_info {
        /** number of the audio format in this slot */
        int format;
@@ -39,23 +68,14 @@ struct slot_info {
 };
 
 /**
- * the main task of audiod
- *
- * \sa struct task, struct sched
- */
-struct audiod_task {
-       struct timeval *now;
-       struct task task;
-};
-
-/**
- * the task for audiod's child (para_client stat)
+ * the task for obtaining para_server's status (para_client stat)
  *
  * \sa struct task, struct sched
  */
 struct status_task {
        /** the associated task structure of audiod */
        struct task task;
+       /** client data associated with the stat task */
        struct private_client_data *pcd;
        /** the array of status items sent by para_server */
        char *stat_item_values[NUM_STAT_ITEMS];
@@ -69,12 +89,16 @@ struct status_task {
        int length_seconds;
        /** the start of the current stream from the view of para_server */
        struct timeval server_stream_start;
-       /** the averaged time deviation between para_server and para_audiod */
+       /** the average time deviation between para_server and para_audiod */
        struct timeval sa_time_diff;
        /** whether client time is ahead of server time */
        int sa_time_diff_sign;
-       /** non-zero if \a af_status is "playing" */
+       /** non-zero if para_server's status is "playing" */
        int playing;
+       /** number of times the clock difference is to be checked */
+       unsigned clock_diff_count;
+       /** when to start the next check for clock difference */
+       struct timeval clock_diff_barrier;
 };
 
 extern struct status_task *stat_task;